{% extends "base.html" %}

{% block title %} | Your email address verification{% endblock %}
{% block bodydata %} class="login" {% endblock %}

{% block main %}
<div class="container">
    <div class="row">
        <div class="col-sm-8 col-sm-offset-2 col-md-6 col-md-offset-3">
            <h3 class="header">Verify email address</h3>
            {% include 'snippets/messages.html' %}

            <div class="alert alert-info">
                <p>We have sent an email to you for verification. Follow the link provided to finalise the sign up process. Please contact us if you do not receive it within a few minutes.</p>
            </div>
        </div>
    </div>
</div>
{% endblock %}
