{% extends "base.html" %}

{% block title %} | Your password reset{% endblock %}
{% block bodydata %} class="login" {% endblock %}

{% block main %}
<div class="container">
    <div class="row">
        <div class="col-sm-8 col-sm-offset-2 col-md-6 col-md-offset-3">
            <h3 class="header">Reset password</h3>
            {% include 'snippets/messages.html' %}

            <form role="form" action="{% url 'account_reset_password' %}" method="POST" novalidate>
                {% csrf_token %}

                <div class="form-group">
                    <label for="email">Please enter your email address to receive reset instructions</label>
                    <input type="email" class="form-control input-lg" name="email" id="email" required />
                </div>

                <div class="form-group">
                    <button type="submit" class="btn btn-primary">Reset password</button>
                </div>
            </form>

            <div class="well text-center">Not a member yet? Please <a href="{% url 'account_signup' %}">sign up here</a></div>
        </div>
    </div>
</div>
{% endblock %}
